<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "fflb";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => 'Fancy Facebook Like Box',
        // Name that appears at the top of your panel
        'display_version'      => '1.0',
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Fancy Facebook Like Box', 'fancy-facebook-like-box' ),
        'page_title'           => __( 'Fancy Facebook Like Box', 'fancy-facebook-like-box' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => false,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'fancy-facebook-like-box',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => false,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );
    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://plus.google.com/+Webgensis',
        'title' => 'Visit us on Google Plus',
        'icon'  => 'el el-googleplus'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/Webgensis',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'https://twitter.com/webgensis',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.linkedin.com/company/webgensis',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );
    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'fancy-facebook-like-box' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'fancy-facebook-like-box' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'fancy-facebook-like-box' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'fancy-facebook-like-box' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'fancy-facebook-like-box' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    Redux::setSection( $opt_name, array(
        'title'  => __( 'Settings', 'fancy-facebook-like-box' ),
        'id'     => 'social-icons',
       // 'desc'   => __( 'Basic field with no subsections.', 'fancy-facebook-like-box' ),
        'icon'   => 'el el-home',
        'fields' => array(
		 	array(
                'id'       => 'enable-popup',
                'type'     => 'switch',
                'title'    => __( 'Enable Popup', 'fancy-facebook-like-box' ),
                //'subtitle' => __( 'Look, it\'s on!', 'fancy-facebook-like-box' ),
                'default'  => true,
				'hint'     => array(
                    'content' => 'if you are using shortcode , then you can disable popup.',
                )
            ),
            array(
                'id'       => 'fb-page-url',
                'type'     => 'text',
				'title'    => __( 'Facebook Page URL', 'fancy-facebook-like-box' ),
				'default'  => 'https://www.facebook.com/Webgensis',
               // 'desc'     => __( 'Example description.', 'fancy-facebook-like-box' ),
               // 'subtitle' => __( 'Example subtitle.', 'fancy-facebook-like-box' ),
               /* 'hint'     => array(
                    'content' => 'This is a <b>hint</b> tool-tip for the text field.<br/><br/>Add any HTML based text you like here.',
                )*/
            ),
			   array(
                'id'       => 'width',
                'type'     => 'text',
                'title'    => __( 'Width', 'fancy-facebook-like-box' ),
                'desc'     => __( 'The pixel width of the embed (Min. 180 to Max. 500)', 'fancy-facebook-like-box' ),
               // 'subtitle' => __( 'Example subtitle.', 'fancy-facebook-like-box' ),
               /* 'hint'     => array(
                    'content' => 'This is a <b>hint</b> tool-tip for the text field.<br/><br/>Add any HTML based text you like here.',
                )*/
            ),
			array(
                'id'       => 'height',
                'type'     => 'text',
                'title'    => __( 'Height', 'fancy-facebook-like-box' ),
               'desc'     => __( 'The pixel height of the embed (Min. 70)', 'fancy-facebook-like-box' ),
               // 'subtitle' => __( 'Example subtitle.', 'fancy-facebook-like-box' ),
               /* 'hint'     => array(
                    'content' => 'This is a <b>hint</b> tool-tip for the text field.<br/><br/>Add any HTML based text you like here.',
                )*/
            ),
			 array(
                'id'       => 'small-header',
                'type'     => 'switch',
                'title'    => __( 'Use Small Header', 'fancy-facebook-like-box' ),
                //'subtitle' => __( 'Look, it\'s on!', 'fancy-facebook-like-box' ),
                'default'  => true,
				'hint'     => array(
                    'content' => 'Uses a smaller version of the page header',
                )
				
            ),
			 array(
                'id'       => 'hide-cover-photo',
                'type'     => 'switch',
                'title'    => __( 'Hide Cover Photo', 'fancy-facebook-like-box' ),
                //'subtitle' => __( 'Look, it\'s on!', 'fancy-facebook-like-box' ),
                'default'  => true,
				'hint'     => array(
                    'content' => 'Hide the cover photo in the header',
                )
            ),
			
			 array(
                'id'       => 'show-faces',
                'type'     => 'switch',
                'title'    => __( 'Show Friend&acute;s Faces', 'fancy-facebook-like-box' ),
                //'subtitle' => __( 'Look, it\'s on!', 'fancy-facebook-like-box' ),
                'default'  => true,
				'hint'     => array(
                    'content' => 'Show profile photos when friends like this',
                )
            ),
			array(
                'id'       => 'adapt-container-width',
                'type'     => 'switch',
                'title'    => __( 'Adapt to plugin container width', 'fancy-facebook-like-box' ),
                //'subtitle' => __( 'Look, it\'s on!', 'fancy-facebook-like-box' ),
                'default'  => true,
				'hint'     => array(
                    'content' => 'Plugin will try to fit inside the container',
                )
				
            ),
			
        )
    ) );
	
    Redux::setSection( $opt_name, array(
        'title'  => __( 'Shortcode', 'fancy-facebook-like-box' ),
        'id'     => 'shortcode-icon',
       // 'desc'   => __( 'Basic field with no subsections.', 'fancy-facebook-like-box' ),
        'icon'   => 'el el-info-circle',
        'fields' => array(
            array(
                'id'   => 'shortcode-info',
                'type' => 'info',
                'desc' => __( 'You can use like box in sidebar or in any page by using shortcode. Shortcode is : [fflb]', 'fancy-facebook-like-box' )
            ),
        )
    ) );